Module error

Module error 

Contains the error-related types for the bson crate.

Structs

Error
An error that can occur in the bson crate.

Enums

Decimal128ErrorKind
The kinds of errors that can occur when working with the Decimal128 type.
ErrorKind
The types of errors that can occur in the bson crate.
ObjectIdErrorKind
The kinds of errors that can occur when working with the ObjectId type.
UuidErrorKind
The kinds of errors that can occur when working with the Uuid type.
ValueAccessErrorKind
The types of errors that can occur when attempting to access a value in a document.

Type Aliases

Result
The result type for all methods that can return an error in the bson crate.