deserialize_from_document

Function deserialize_from_document 

pub fn deserialize_from_document<T>(doc: Document) -> Result<T>
Available on crate feature serde only.
Deserialize a T from the provided Document.

The Deserializer used by this function presents itself as human readable, whereas the one used in deserialize_from_slice does not. This means that this function may deserialize differently than deserialize_from_slice for types that change their deserialization logic depending on whether the format is human readable or not.