Contains the error-related types for the bson crate.
Structs
- Error
- An error that can occur in the
bsoncrate.
Enums
- Decimal128
Error Kind - The kinds of errors that can occur when working with the
Decimal128type. - Error
Kind - The types of errors that can occur in the
bsoncrate. - Object
IdError Kind - The kinds of errors that can occur when working with the
ObjectIdtype. - Uuid
Error Kind - The kinds of errors that can occur when working with the
Uuidtype. - Value
Access Error Kind - The types of errors that can occur when attempting to access a value in a document.
Type Aliases
- Result
- The result type for all methods that can return an error in the
bsoncrate.