pub fn deserialize_from_document<T>(doc: Document) -> Result<T>where
T: DeserializeOwned,Available on crate feature
serde only.Expand description
Deserialize a T from the provided Document.
The Deserializer used by this function presents itself as human readable, whereas the
one used in deserialize_from_slice does not. This means that this function may deserialize
differently than deserialize_from_slice for types that change their deserialization logic
depending on whether the format is human readable or not.