[−][src]Enum bson::spec::ElementType
All available BSON element types.
Not all element types are representable by the Bson type.
Variants
64-bit binary floating point
UTF-8 string
Embedded document
Array
Binary data
Deprecated. Undefined (value)
Boolean value
UTC datetime
Null value
Regular expression - The first cstring is the regex pattern, the second is the regex options string. Options are identified by characters, which must be stored in alphabetical order. Valid options are 'i' for case insensitive matching, 'm' for multiline matching, 'x' for verbose mode, 'l' to make \w, \W, etc. locale dependent, 's' for dotall mode ('.' matches everything), and 'u' to make \w, \W, etc. match unicode.
Deprecated.
JavaScript code
Deprecated.
JavaScript code w/ scope
32-bit integer
Timestamp
64-bit integer
Methods
impl ElementType[src]
pub fn from(tag: u8) -> Option<ElementType>[src]
Attempt to convert from a u8.